/*
  Internet Radio with Volume Demo, adapted to also PWM Fade an LED Strip in 2024
  esp32-i2s-radio-volume.ino
  ESP32 I2S radio with volume control
  Uses two MAX98357 I2S Amplifier Modules, strapped for Left and Right channel
  Uses ESP32-audioI2S Library - https://github.com/schreibfaul1/ESP32-audioI2S

  DroneBot Workshop 2022
  https://dronebotworkshop.com
  
  Adapted by Marius Araújo 2024 for his Fab Academt Final Project
  https://fabacademy.org/2020/labs/fct/students/marius-araujo/

  with help and support by Adrián Torres
  https://fabacademy.org/2020/labs/leon/students/adrian-torres/

  https://fablableon.org/
*/

// Include required libraries
#include "Arduino.h"
#include "WiFi.h"
#include "Audio.h"

// Define I2S connections
#define I2S_DOUT  33
#define I2S_BCLK  25
#define I2S_LRC   26

// Define volume control pot connection
// ADC3 is GPIO 39
const int volControl = 39;

// Integer for volume level
int volume = 10;

// Create audio object
Audio audio;

// Wifi Credentials
String ssid =    "YOUR WIFI SSID";
String password = "YOUR WIFI PASSWORD";


// Variables for LED control with potenciometer
int BRIGHTNESS = 0;
int pinPot = 34; // IN Pin potencipmeter
int pinLed = 12;  // OUT Pin to LED Strip
const int frequency = 1000;
const int channel = 0;
const int resolution = 10;

void setup() {

  // Start Serial Monitor
  Serial.begin(115200);

  // Setup WiFi in Station mode
  WiFi.disconnect();
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid.c_str(), password.c_str());

  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }

  // WiFi Connected, print IP to serial monitor
  Serial.println("");
  Serial.println("WiFi connected");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());
  Serial.println("");

  // Connect MAX98357 I2S Amplifier Module
  audio.setPinout(I2S_BCLK, I2S_LRC, I2S_DOUT);

  // Set the volume
  audio.setVolume(volume);

  // Connect to an Internet radio station (select one as desired)
  //audio.connecttohost("http://vis.media-ice.musicradio.com/CapitalMP3");
  //audio.connecttohost("mediaserv30.live-nect MAX98357 I2S Amplifier Module
  //audio.connecttohost("www.surfmusic.de/m3u/100-5-das-hitradio,4529.m3u");
  //audio.connecttohost("stream.1a-webradio.de/deutsch/mp3-128/vtuner-1a");
  //audio.connecttohost("www.antenne.de/webradio/antenne.m3u");
  audio.connecttohost("0n-80s.radionetz.de:8000/0n-70s.mp3");
  
  
  // Potentiometer LED Control Configuration
  ledcSetup(channel, frequency, resolution);
  ledcAttachPin(pinLed, channel); // in order to use ledcAttachPin correctly
}

void loop()

{
  // Run audio player
  audio.loop();

  // Get the volume level
  volume = map ((analogRead(volControl)), 0, 4095, 0 , 100);

  // Set the volume
  audio.setVolume(volume);

 // Potentiometer LED Control
  BRIGHTNESS = analogRead(pinPot);
  BRIGHTNESS = map(BRIGHTNESS, 0, 1023, 0, 255);
  ledcWrite(channel, BRIGHTNESS);

}
  
// Audio status functions

void audio_info(const char *info) {
  Serial.print("info        "); Serial.println(info);
}
void audio_id3data(const char *info) { //id3 metadata
  Serial.print("id3data     "); Serial.println(info);
}
void audio_eof_mp3(const char *info) { //end of file
  Serial.print("eof_mp3     "); Serial.println(info);
}
void audio_showstation(const char *info) {
  Serial.print("station     "); Serial.println(info);
}
void audio_showstreaminfo(const char *info) {
  Serial.print("streaminfo  "); Serial.println(info);
}
void audio_showstreamtitle(const char *info) {
  Serial.print("streamtitle "); Serial.println(info);
}
void audio_bitrate(const char *info) {
  Serial.print("bitrate     "); Serial.println(info);
}
void audio_commercial(const char *info) { //duration in sec
  Serial.print("commercial  "); Serial.println(info);
}
void audio_icyurl(const char *info) { //homepage
  Serial.print("icyurl      "); Serial.println(info);
}
void audio_lasthost(const char *info) { //stream URL played
  Serial.print("lasthost    "); Serial.println(info);
}
void audio_eof_speech(const char *info) {
  Serial.print("eof_speech  "); Serial.println(info);
}